==> artery-document-metadata-1.13.25-sources.jar: com/xforceplus/ultraman/app/arterydocument/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.arterydocument.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2024-07-25
 */

public class PageMeta {
    public interface AccountMapping {
        static String code() {
            return "accountMapping";
        }
        static String name() {
            return "商超账号映射";
        }
    }
    public interface ServiceApplication {
        static String code() {
            return "serviceApplication";
        }
        static String name() {
            return "自助服务启停申请";
        }
    }
    public interface CustomBillingOp {
        static String code() {
            return "customBillingOp";
        }
        static String name() {
            return "billing单运维";
        }
    }
    public interface Po {
        static String code() {
            return "po";
        }
        static String name() {
            return "采购订单列表";
        }
    }
    public interface RtvOrder {
        static String code() {
            return "rtvOrder";
        }
        static String name() {
            return "转换后退货单";
        }
    }
    public interface PerformanceTransfer {
        static String code() {
            return "performanceTransfer";
        }
        static String name() {
            return "退货单转换查询";
        }
    }
    public interface PosAndIrTransfer {
        static String code() {
            return "posAndIrTransfer";
        }
        static String name() {
            return "POS转换查询";
        }
    }
    public interface Settlement {
        static String code() {
            return "settlement";
        }
        static String name() {
            return "结算单查询";
        }
    }
    public interface ImportFileCheckConfig {
        static String code() {
            return "importFileCheckConfig";
        }
        static String name() {
            return "导入文件字段校验配置";
        }
    }
    public interface ExecuteTasks {
        static String code() {
            return "executeTasks";
        }
        static String name() {
            return "执行页面查询";
        }
    }
    public interface DeliveryAppointment {
        static String code() {
            return "deliveryAppointment";
        }
        static String name() {
            return "送货预约查询";
        }
    }
    public interface MarketAccountRoleConfig {
        static String code() {
            return "marketAccountRoleConfig";
        }
        static String name() {
            return "商超账号权限维护";
        }
    }
    public interface MarketAccountCenter {
        static String code() {
            return "marketAccountCenter";
        }
        static String name() {
            return "商超账户中心";
        }
    }
    public interface DocumentUnsendRecord {
        static String code() {
            return "documentUnsendRecord";
        }
        static String name() {
            return "单据未下发记录";
        }
    }
    public interface BusinessTagView {
        static String code() {
            return "businessTagView";
        }
        static String name() {
            return "单据检查标签配置";
        }
    }
    public interface PurchaseOrgs {
        static String code() {
            return "purchaseOrgs";
        }
        static String name() {
            return "卖场门店基础数据";
        }
    }
    public interface RtvTransfer {
        static String code() {
            return "rtvTransfer";
        }
        static String name() {
            return "收货单转换查询";
        }
    }
    public interface Rtv {
        static String code() {
            return "rtv";
        }
        static String name() {
            return "退货单列表";
        }
    }
    public interface AddressDemo {
        static String code() {
            return "addressDemo";
        }
        static String name() {
            return "地址Demo";
        }
    }
    public interface Tabcode {
        static String code() {
            return "tabcode";
        }
        static String name() {
            return "商品场景码配置";
        }
    }
    public interface SalesOrder {
        static String code() {
            return "salesOrder";
        }
        static String name() {
            return "销售订单查询";
        }
    }
    public interface OrigoodsReceiveNote {
        static String code() {
            return "origoodsReceiveNote";
        }
        static String name() {
            return "原始收货单";
        }
    }
    public interface WalmartInvoiceBackfilling {
        static String code() {
            return "walmartInvoiceBackfilling";
        }
        static String name() {
            return "沃尔玛发票回填查询";
        }
    }
    public interface SchemaCodeMapping {
        static String code() {
            return "schemaCodeMapping";
        }
        static String name() {
            return "客商场景码配置";
        }
    }
    public interface PosBackTracking {
        static String code() {
            return "PosBackTracking";
        }
        static String name() {
            return "POS数据自动补录";
        }
    }
    public interface TenantTransferQuery {
        static String code() {
            return "tenantTransferQuery";
        }
        static String name() {
            return "租户单据转换查询";
        }
    }
    public interface Pos {
        static String code() {
            return "pos";
        }
        static String name() {
            return "转换后POS数据";
        }
    }
    public interface BillingManageMent {
        static String code() {
            return "billingManageMent";
        }
        static String name() {
            return "billing单管理";
        }
    }
    public interface DocumentSendControl {
        static String code() {
            return "documentSendControl";
        }
        static String name() {
            return "单据下发控制";
        }
    }
    public interface Originalinventory {
        static String code() {
            return "originalinventory";
        }
        static String name() {
            return "原始库存数据";
        }
    }
    public interface Ir {
        static String code() {
            return "ir";
        }
        static String name() {
            return "库存单列表";
        }
    }
    public interface OrderGoodsManageNum {
        static String code() {
            return "orderGoodsManageNum";
        }
        static String name() {
            return "订单商品控量管理";
        }
    }
    public interface PosIrConversionRecordOperation {
        static String code() {
            return "PosIrConversionRecordOperation";
        }
        static String name() {
            return "（运维使用）POS和库存转换记录查询";
        }
    }
    public interface MarketAccountChannelConfig {
        static String code() {
            return "marketAccountChannelConfig";
        }
        static String name() {
            return "账号单据渠道配置";
        }
    }
    public interface IrTransfer {
        static String code() {
            return "IrTransfer";
        }
        static String name() {
            return "库存转换查询";
        }
    }
    public interface OriginalPos {
        static String code() {
            return "originalPos";
        }
        static String name() {
            return "原始销售（POS）查询";
        }
    }
    public interface ImportWizard {
        static String code() {
            return "importWizard";
        }
        static String name() {
            return "导入向导示例";
        }
    }
    public interface CustomerGoods {
        static String code() {
            return "customerGoods";
        }
        static String name() {
            return "卖场物料基础数据";
        }
    }
    public interface TenantTransferOperation {
        static String code() {
            return "tenantTransferOperation";
        }
        static String name() {
            return "租户单据转换运维";
        }
    }
    public interface So {
        static String code() {
            return "so";
        }
        static String name() {
            return "销售出库单列表";
        }
    }
    public interface AccountingDocCheck {
        static String code() {
            return "accountingDocCheck";
        }
        static String name() {
            return "凭证管理";
        }
    }
    public interface BillingDiscountDetail {
        static String code() {
            return "billingDiscountDetail";
        }
        static String name() {
            return "billing折扣明细";
        }
    }
    public interface ProductDataAnalysis {
        static String code() {
            return "productDataAnalysis";
        }
        static String name() {
            return "商品市场数据分析";
        }
    }
    public interface SupermarketRewrite {
        static String code() {
            return "supermarketRewrite";
        }
        static String name() {
            return "商超回写";
        }
    }
    public interface HuaweiCloudOrder {
        static String code() {
            return "huaweiCloudOrder";
        }
        static String name() {
            return "华为云订单";
        }
    }
    public interface GoodsReceiveNote {
        static String code() {
            return "goodsReceiveNote";
        }
        static String name() {
            return "转换后收货单";
        }
    }
    public interface WalmartPO {
        static String code() {
            return "walmartPO";
        }
        static String name() {
            return "沃尔玛订单余额查询";
        }
    }
    public interface Inventory {
        static String code() {
            return "inventory";
        }
        static String name() {
            return "转换后库存数据";
        }
    }
}

==> artery-document-metadata-1.14.182-sources.jar: com/xforceplus/ultraman/app/arterydocument/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.arterydocument.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2024-12-20
 */

public class PageMeta {
    public interface AccountMapping {
        static String code() {
            return "accountMapping";
        }
        static String name() {
            return "商超账号映射";
        }
    }
    public interface ImportFileCheckConfig {
        static String code() {
            return "importFileCheckConfig";
        }
        static String name() {
            return "导入文件字段校验配置";
        }
    }
    public interface MarketAccountRoleConfig {
        static String code() {
            return "marketAccountRoleConfig";
        }
        static String name() {
            return "商超账号权限维护";
        }
    }
    public interface CustomBillingOp {
        static String code() {
            return "customBillingOp";
        }
        static String name() {
            return "billing单运维";
        }
    }
    public interface RtvOrder {
        static String code() {
            return "rtvOrder";
        }
        static String name() {
            return "转换后退货单";
        }
    }
    public interface BusinessTagView {
        static String code() {
            return "businessTagView";
        }
        static String name() {
            return "单据检查标签配置";
        }
    }
    public interface PurchaseOrgs {
        static String code() {
            return "purchaseOrgs";
        }
        static String name() {
            return "卖场门店基础数据";
        }
    }
    public interface MarketAccountCenter {
        static String code() {
            return "marketAccountCenter";
        }
        static String name() {
            return "商超账户中心";
        }
    }
    public interface RetryConfig {
        static String code() {
            return "retryConfig";
        }
        static String name() {
            return "重试策略配置";
        }
    }
    public interface Rtv {
        static String code() {
            return "rtv";
        }
        static String name() {
            return "退货单列表";
        }
    }
    public interface AddressDemo {
        static String code() {
            return "addressDemo";
        }
        static String name() {
            return "地址Demo";
        }
    }
    public interface SupermarketStoreInfo {
        static String code() {
            return "supermarketStoreInfo";
        }
        static String name() {
            return "商超门店基础信息";
        }
    }
    public interface OrigoodsReceiveNote {
        static String code() {
            return "origoodsReceiveNote";
        }
        static String name() {
            return "原始收货单";
        }
    }
    public interface SalesOrder {
        static String code() {
            return "salesOrder";
        }
        static String name() {
            return "销售订单查询";
        }
    }
    public interface WalmartInvoiceBackfilling {
        static String code() {
            return "walmartInvoiceBackfilling";
        }
        static String name() {
            return "沃尔玛发票回填查询";
        }
    }
    public interface MarketAccountChannelConfig {
        static String code() {
            return "marketAccountChannelConfig";
        }
        static String name() {
            return "账号单据渠道配置";
        }
    }
    public interface Originalinventory {
        static String code() {
            return "originalinventory";
        }
        static String name() {
            return "原始库存数据";
        }
    }
    public interface OrderGoodsManageNum {
        static String code() {
            return "orderGoodsManageNum";
        }
        static String name() {
            return "订单商品控量管理";
        }
    }
    public interface PocBSorder {
        static String code() {
            return "pocBSorder";
        }
        static String name() {
            return "经销商销售单及销售退单";
        }
    }
    public interface PosIrConversionRecordOperation {
        static String code() {
            return "PosIrConversionRecordOperation";
        }
        static String name() {
            return "（运维使用）POS和库存转换记录查询";
        }
    }
    public interface IrTransfer {
        static String code() {
            return "IrTransfer";
        }
        static String name() {
            return "库存转换查询";
        }
    }
    public interface AccountingDocCheck {
        static String code() {
            return "accountingDocCheck";
        }
        static String name() {
            return "凭证管理";
        }
    }
    public interface BillingDiscountDetail {
        static String code() {
            return "billingDiscountDetail";
        }
        static String name() {
            return "billing折扣明细";
        }
    }
    public interface ProductDataAnalysis {
        static String code() {
            return "productDataAnalysis";
        }
        static String name() {
            return "商品市场数据分析";
        }
    }
    public interface SupermarketRewrite {
        static String code() {
            return "supermarketRewrite";
        }
        static String name() {
            return "商超回写";
        }
    }
    public interface CustomerGoods {
        static String code() {
            return "customerGoods";
        }
        static String name() {
            return "卖场物料基础数据";
        }
    }
    public interface WalmartPO {
        static String code() {
            return "walmartPO";
        }
        static String name() {
            return "沃尔玛订单余额查询";
        }
    }
    public interface Inventory {
        static String code() {
            return "inventory";
        }
        static String name() {
            return "转换后库存数据";
        }
    }
    public interface ServiceApplication {
        static String code() {
            return "serviceApplication";
        }
        static String name() {
            return "自助服务启停申请";
        }
    }
    public interface DocumentUnsendRecord {
        static String code() {
            return "documentUnsendRecord";
        }
        static String name() {
            return "单据未下发记录";
        }
    }
    public interface RetryTask {
        static String code() {
            return "retryTask";
        }
        static String name() {
            return "重试任务";
        }
    }
    public interface ExpenseDoc {
        static String code() {
            return "expenseDoc";
        }
        static String name() {
            return "费用单查询";
        }
    }
    public interface Po {
        static String code() {
            return "po";
        }
        static String name() {
            return "采购订单列表";
        }
    }
    public interface FinancialRTV {
        static String code() {
            return "financialRTV";
        }
        static String name() {
            return "转换后退货单（财务）";
        }
    }
    public interface PerformanceTransfer {
        static String code() {
            return "performanceTransfer";
        }
        static String name() {
            return "退货单转换查询";
        }
    }
    public interface PosAndIrTransfer {
        static String code() {
            return "posAndIrTransfer";
        }
        static String name() {
            return "POS转换查询";
        }
    }
    public interface Settlement {
        static String code() {
            return "settlement";
        }
        static String name() {
            return "结算单查询";
        }
    }
    public interface SettlementGrnRtvDetails {
        static String code() {
            return "settlementGrnRtvDetails";
        }
        static String name() {
            return "结算单收退货明细";
        }
    }
    public interface SettlementDoc {
        static String code() {
            return "settlementDoc";
        }
        static String name() {
            return "结算单查询";
        }
    }
    public interface RtvTransfer {
        static String code() {
            return "rtvTransfer";
        }
        static String name() {
            return "收货单转换查询";
        }
    }
    public interface ExecuteTasks {
        static String code() {
            return "executeTasks";
        }
        static String name() {
            return "执行页面查询";
        }
    }
    public interface DeliveryAppointment {
        static String code() {
            return "deliveryAppointment";
        }
        static String name() {
            return "送货预约查询";
        }
    }
    public interface Tabcode {
        static String code() {
            return "tabcode";
        }
        static String name() {
            return "商品场景码配置";
        }
    }
    public interface Pos {
        static String code() {
            return "pos";
        }
        static String name() {
            return "转换后POS数据";
        }
    }
    public interface SchemaCodeMapping {
        static String code() {
            return "schemaCodeMapping";
        }
        static String name() {
            return "客商场景码配置";
        }
    }
    public interface PosBackTracking {
        static String code() {
            return "PosBackTracking";
        }
        static String name() {
            return "POS数据自动补录";
        }
    }
    public interface TenantTransferQuery {
        static String code() {
            return "tenantTransferQuery";
        }
        static String name() {
            return "租户单据转换查询";
        }
    }
    public interface DocumentSendControl {
        static String code() {
            return "documentSendControl";
        }
        static String name() {
            return "单据下发控制";
        }
    }
    public interface BillingManageMent {
        static String code() {
            return "billingManageMent";
        }
        static String name() {
            return "billing单管理";
        }
    }
    public interface Ir {
        static String code() {
            return "ir";
        }
        static String name() {
            return "库存单列表";
        }
    }
    public interface PaymentDoc {
        static String code() {
            return "paymentDoc";
        }
        static String name() {
            return "付款单查询";
        }
    }
    public interface OriginalPos {
        static String code() {
            return "originalPos";
        }
        static String name() {
            return "原始销售（POS）查询";
        }
    }
    public interface So {
        static String code() {
            return "so";
        }
        static String name() {
            return "销售出库单列表";
        }
    }
    public interface ImportWizard {
        static String code() {
            return "importWizard";
        }
        static String name() {
            return "导入向导示例";
        }
    }
    public interface TenantTransferOperation {
        static String code() {
            return "tenantTransferOperation";
        }
        static String name() {
            return "租户单据转换运维";
        }
    }
    public interface HuaweiCloudOrder {
        static String code() {
            return "huaweiCloudOrder";
        }
        static String name() {
            return "华为云订单";
        }
    }
    public interface GoodsReceiveNote {
        static String code() {
            return "goodsReceiveNote";
        }
        static String name() {
            return "转换后收货单";
        }
    }
    public interface NewfinancialRTV {
        static String code() {
            return "NewfinancialRTV";
        }
        static String name() {
            return "转换后退货单（财务）新";
        }
    }
    public interface YwPos {
        static String code() {
            return "ywPos";
        }
        static String name() {
            return "（运维查询）POS数据";
        }
    }
}
